@@ -15,10 +15,15 @@ from pdfobjects.pdfttfonts import PDFTTFont
 from pdfobjects.pdfmargin import PDFMargin
 from pdfobjects.pdfcellformat import PDFCellFormat
 from pdfobjects.pdfhtml import PDFHtml
+from pdfobjects.pdfellipse import PDFEllipse
+from pdfobjects.pdfarc import PDFArc
+from pdfobjects.pdflinegraph import PDFLineGraph
+from pdfobjects.pdfxyscatter import PDFXYScatter
+from pdfobjects.pdfpiechart import PDFPieChart
+from pdfobjects.pdfbarchart import PDFBarChart, PDFMultiBarChart
 
 
 class PDFDocument(object):
-
     """ The Document object is the base class that
         is used to add and manage the content of the
         pdf file.
@@ -64,9 +69,7 @@ class PDFDocument(object):
 
     def _set_color_scheme(self, draw_color=None, fill_color=None, text_color=None):
         """ Default color object is black letters
-            & black lines.
-
-        """
+            & black lines."""
         if draw_color is None:
             draw_color = PDFColor()
             draw_color._set_type('d')
@@ -82,20 +85,26 @@ class PDFDocument(object):
         self.text_color = text_color
 
     def set_text_color(self, color):
-        self.text_color = color
+        if isinstance(color, PDFColor):
+            self.text_color = color
+        else:
+            raise ValueError("Not a PDFColor instance")
 
     def set_fill_color(self, color):
-        self.fill_color = color
+        if isinstance(color, PDFColor):
+            self.fill_color = color
+        else:
+            raise ValueError("Not a PDFColor instance")
 
     def set_draw_color(self, color):
-        self.draw_color = color
+        if isinstance(color, PDFColor):
+            self.draw_color = color
+        else:
+            raise ValueError("Not a PDFColor instance")
 
     def _set_default_font(self):
-        """ Internal method to set the
-            initial default font. Change
-            the font using set_font method.
-
-        """
+        """ Internal method to set the initial default font. Change
+            the font using set_font method."""
         self.font = PDFFont(self.session)
         self.font._set_index()
         self.fonts.append(self.font)
@@ -108,11 +117,8 @@ class PDFDocument(object):
     # Public methods, main interface
     # Pages
     def add_page(self, page=None):
-        """ May generate and add a PDFPage
-            separately, or use this to generate
-            a default page.
-
-        """
+        """ May generate and add a PDFPage separately, or use this to generate
+            a default page."""
         if page is None:
             self.page = PDFPage(self.orientation_default, self.layout_default, self.margins)
         else:
@@ -170,15 +176,8 @@ class PDFDocument(object):
 
     # Font
     def set_font(self, family=None, style='', size=None, font=None):
-        """ Set the document font object, size given in points.
-            If family, style, and/or size is given, generates
-            a new Font object, checks to see if it is already
-            in use, and selects it.
-
-            May also use the font keyword to add an already
-            instantiated PDFFont object.
-
-        """
+        """ Set the document font object, size given in points. If family, style, and/or size is given, generates
+            a new Font object, checks to see if it is already in use, and selects it. """
         if font:
             testfont = font
         elif isinstance(family, PDFFont):
@@ -218,9 +217,7 @@ class PDFDocument(object):
 
     def get_font(self):
         """ Get the current font object. Useful for storing
-            in variables, and switching between styles.
-
-        """
+            in variables, and switching between styles. """
         return self.font
 
     def set_font_size(self, size):
@@ -230,20 +227,16 @@ class PDFDocument(object):
         else:
             self.font._set_size(size)
 
+    def get_font_size(self):
+        return self.font.font_size
+
     def print_available_fonts(self):
         print PDFTTFont.available_fonts()
 
     # Writing
     def add_text(self, text, cursor=None):
-        """ Input text, short or long. Writes in order, within the
-            pre-defined page boundaries. Use add_newline as a return
-            character. Sequential add_text commands will print without
-            additional whitespace.
-
-            Currently all "left-justified", although that may change in
-            future version.
-
-        """
+        """ Input text, short or long. Writes in order, within the defined page boundaries. Sequential add_text commands will print without
+            additional whitespace. """
         if cursor is None:
             cursor = self.page.cursor
 
@@ -257,13 +250,18 @@ class PDFDocument(object):
         else:
             PDFText(self.session, self.page, text, self.font, self.text_color, cursor, self.justification, self.double_spacing)
 
+    def draw_text(self, *args, **kwargs):
+        self.add_text(*args, **kwargs)
+
+    def text(self, *args, **kwargs):
+        self.add_text(*args, **kwargs)
+
     def double_space(self, multiplier=1):
         self.double_spacing = multiplier
 
     def add_newline(self, number=1):
         """ Starts over again at the new line. If number is specified,
-            it will leave multiple lines.
-        """
+            it will leave multiple lines."""
         if isinstance(number, int):
             try:
                 self.page._add_newline(self.font, number, self.double_spacing)
@@ -272,11 +270,17 @@ class PDFDocument(object):
         else:
             raise TypeError("Number of newlines must be an integer.")
 
+    def newline(self, *args, **kwargs):
+        self.add_newline(*args, **kwargs)
+
     def add_indent(self, spaces=4):
         """ Adds a standard tab of 4 spaces.
         """
         self.page._add_indent(self.font, spaces)
 
+    def indent(self, *args, **kwargs):
+        self.add_indent(*args, **kwargs)
+
     def start_block_indent(self, px=20):
         self.px = px
         self.page.cursor.x_plus(self.px)
@@ -318,6 +322,9 @@ class PDFDocument(object):
                     self.add_text(' %s' % arg)
                     self.add_newline(2)
 
+    def list(self, *args, **kwargs):
+        self.add_list(*args, **kwargs)
+
     def add_html(self, htmltext, context=None, formats=None, cursor=None):
         if cursor is not None:
             self.set_cursor(cursor)
@@ -327,28 +334,44 @@ class PDFDocument(object):
 
         PDFHtml(self, self.session, htmltext, formats, context)
 
-    def add_line(self, x1=None, y1=None, x2=None, y2=None, cursor1=None, cursor2=None, style="solid"):
+    def html(self, *args, **kwargs):
+        self.add_html(*args, **kwargs)
+
+    # Shapes
+    def add_line(self, x1=None, y1=None, x2=None, y2=None, cursor1=None, cursor2=None, stroke="solid"):
         if cursor1 is not None:
             if cursor2 is not None:
                 pass
             elif x2 is not None and y2 is not None:
-                cursor2 = PDFCursor(x2, y2)
+                cursor2 = self.page.cursor.copy()
+                cursor2.x = x2
+                cursor2.y = y2
             else:
                 raise Exception("Line not fully specified")
         elif x1 is not None and y1 is not None:
-            cursor1 = PDFCursor(x1, y1)
+            cursor1 = self.page.cursor.copy()
+            cursor1.x = x1
+            cursor1.y = y1
             if cursor2 is not None:
                 pass
             elif x2 is not None and y2 is not None:
-                cursor2 = PDFCursor(x2, y2)
+                cursor2 = self.page.cursor.copy()
+                cursor2.x = x2
+                cursor2.y = y2
             else:
                 raise Exception("Line not fully specified")
         else:
             raise Exception("Line not specified")
 
-        myline = PDFLine(self.session, self.page, cursor1, cursor2, self.draw_color, style)
+        myline = PDFLine(self.session, self.page, cursor1, cursor2, self.draw_color, stroke)
         myline._draw()
 
+    def draw_line(self, *args, **kwargs):
+        self.add_line(*args, **kwargs)
+
+    def line(self, *args, **kwargs):
+        self.add_line(*args, **kwargs)
+
     def draw_horizontal_line(self):
         end_cursor = self.page.cursor.copy()
         end_cursor.x = end_cursor.xmax
@@ -356,9 +379,14 @@ class PDFDocument(object):
         myline = PDFLine(self.session, self.page, self.page.cursor, end_cursor, self.draw_color, None)
         myline._draw()
 
-    def draw_rectangle(self, x1=None, y1=None, x2=None, y2=None,
-                       width=None, height=None, cursor1=None, cursor2=None,
-                       style='S', size=1):
+    def add_horizontal_line(self):
+        self.draw_horizontal_line()
+
+    def horizontal_line(self):
+        self.draw_horizontal_line()
+
+    def draw_rectangle(self, x1=None, y1=None, x2=None, y2=None, width=None, height=None, cursor1=None, cursor2=None,
+                       style='S', stroke="solid", size=1):
         if cursor1 is not None:
             if cursor2 is not None:
                 pass
@@ -384,13 +412,128 @@ class PDFDocument(object):
             else:
                 raise Exception("Rectangle not defined")
 
-        rectangle = PDFRectangle(self.session, self.page,
-                                 cursor1, cursor2,
-                                 self.draw_color, self.fill_color,
-                                 None, style, size)
+        rectangle = PDFRectangle(self.session, self.page, cursor1, cursor2, self.draw_color, self.fill_color, style, stroke, size)
 
         rectangle._draw()
 
+    def add_rectangle(self, *args, **kwargs):
+        self.draw_rectangle(*args, **kwargs)
+
+    def rectangle(self, *args, **kwargs):
+        self.draw_rectangle(*args, **kwargs)
+
+    def draw_circle(self, center_cursor, radius, border_color=None, fill_color=None, style="S", stroke='solid', size=1):
+        self.draw_ellipse(center_cursor, radius, radius, border_color, fill_color, style, stroke, size)
+
+    def draw_ellipse(self, center_cursor, x_radius, y_radius, border_color=None, fill_color=None, style="S", stroke='solid', size=1):
+        radius_cursor = PDFCursor(x_radius, y_radius)
+        if isinstance(border_color, PDFColor):
+            border_color = border_color
+        else:
+            border_color = self.draw_color
+        if isinstance(fill_color, PDFColor):
+            fill_color = fill_color
+        else:
+            fill_color = self.fill_color
+
+        circle = PDFEllipse(self.session, self.page, center_cursor, radius_cursor, border_color, fill_color, style, stroke, size)
+        circle._draw()
+
+    def draw_arc(self, center_cursor, radius, starting_angle, arc_angle, inverted=False, end_angle=None, border_color=None, fill_color=None, style='S', stroke='solid', size=1):
+        if isinstance(border_color, PDFColor):
+            border_color = border_color
+        else:
+            border_color = self.draw_color
+        if isinstance(fill_color, PDFColor):
+            fill_color = fill_color
+        else:
+            fill_color = self.fill_color
+
+        arc = PDFArc(self.session, self.page, center_cursor, radius, starting_angle, arc_angle, inverted, end_angle, border_color, fill_color, style, stroke, size)
+        arc._draw()
+
+    # Graphs
+    def add_line_graph(self, data, cursor, width, height, title=None, x_axis_limits=None, y_axis_limits=None, frequency=None, axis_titles=None, axis_labels=None, axis_font_size=None, line_colors=None,
+                       background=None, legend=None, dots=None):
+        save_draw_color = self.draw_color
+        save_fill_color = self.fill_color
+        save_font_size = self.get_font_size()
+        if axis_font_size is None:
+            self.set_font_size(8)
+        else:
+            self.set_font_size(axis_font_size)
+
+        graph = PDFLineGraph(self.session, self.page, cursor, data, width, height, title, x_axis_limits, y_axis_limits, frequency, axis_titles, axis_labels, line_colors, background, legend, dots)
+
+        self.set_font_size(save_font_size)
+        self.set_draw_color(save_draw_color)
+        self.set_fill_color(save_fill_color)
+
+    def add_xy_scatter(self, data, cursor, width, height, title=None, x_axis_limits=None, y_axis_limits=None, frequency=None, axis_titles=None, axis_labels=None, axis_font_size=None, line_colors=None,
+                       background=None, legend=None, dots=None, linear_regression=None, linear_regression_equation=None):
+
+        save_draw_color = self.draw_color
+        save_fill_color = self.fill_color
+        save_font_size = self.get_font_size()
+        if axis_font_size is None:
+            self.set_font_size(8)
+        else:
+            self.set_font_size(axis_font_size)
+
+        graph = PDFXYScatter(self.session, self.page, cursor, data, width, height, title, x_axis_limits, y_axis_limits, frequency, axis_titles, axis_labels, line_colors, background, legend, dots, linear_regression, linear_regression_equation)
+
+        self.set_font_size(save_font_size)
+        self.set_draw_color(save_draw_color)
+        self.set_fill_color(save_fill_color)
+
+    def add_simple_bar_chart(self, data, cursor, width, height, title=None, axis_titles=None, axis_font_size=None, y_axis_limits=None, y_axis_frequency=None, bar_style="B", bar_padding=0.1, bar_border_colors=None, bar_fill_colors=None,
+                             background=None):
+
+        save_draw_color = self.draw_color
+        save_fill_color = self.fill_color
+        save_font_size = self.get_font_size()
+
+        if axis_font_size is None:
+            self.set_font_size(8)
+        else:
+            self.set_font_size(axis_font_size)
+
+        graph = PDFBarChart(self.session, self.page, data, cursor, width, height, title, axis_titles, y_axis_limits, y_axis_frequency, bar_style, bar_padding, bar_border_colors, bar_fill_colors,
+                            background)
+
+        self.set_font_size(save_font_size)
+        self.set_draw_color(save_draw_color)
+        self.set_fill_color(save_fill_color)
+
+    def add_multi_bar_chart(self, data, cursor, width, height, title=None, axis_titles=None, axis_font_size=None, y_axis_limits=None, y_axis_frequency=None, bar_style="B", bar_padding=0.1, bar_border_colors=None, bar_fill_colors=None,
+                            background=None, legend=None):
+        save_draw_color = self.draw_color
+        save_fill_color = self.fill_color
+        save_font_size = self.get_font_size()
+
+        if axis_font_size is None:
+            self.set_font_size(8)
+        else:
+            self.set_font_size(axis_font_size)
+
+        graph = PDFMultiBarChart(self.session, self.page, data, cursor, width, height, title, axis_titles, y_axis_limits, y_axis_frequency, bar_style, bar_padding, bar_border_colors, bar_fill_colors,
+                                 background, legend)
+
+        self.set_font_size(save_font_size)
+        self.set_draw_color(save_draw_color)
+        self.set_fill_color(save_fill_color)
+
+    def add_pie_chart(self, data, cursor, width, height, title=None, data_type="raw", fill_colors=None, labels=False, background=None, legend=None):
+        """ Data type may be "raw" or "percent" """
+        save_draw_color = self.draw_color
+        save_fill_color = self.fill_color
+
+        chart = PDFPieChart(self.session, self.page, data, cursor, width, height, title, data_type, fill_colors, labels, background, legend)
+
+        self.set_draw_color(save_draw_color)
+        self.set_fill_color(save_fill_color)
+
+    # Tables
     def add_table(self, rows, columns, cursor=None):
         if cursor is None:
             cursor = self.page.cursor
@@ -414,6 +557,7 @@ class PDFDocument(object):
         format = PDFCellFormat(data, cell_font)
         return format
 
+    # Images
     def add_image(self, image, name=None):
         if isinstance(image, PDFImage):  # It's an image object
             myimage = self._get_image(image.name)
@@ -481,9 +625,7 @@ class PDFDocument(object):
 
     def _output_pages(self):
         """ Called by the PDFLite object to prompt creating
-            the page objects.
-
-        """
+            the page objects."""
         if self.orientation_changes is None:
             self._get_orientation_changes()
         else:
@@ -551,9 +693,7 @@ class PDFDocument(object):
 
     def _get_orientation_changes(self):
         """ Returns a list of the pages that have
-            orientation changes.
-
-        """
+            orientation changes."""
         self.orientation_changes = []
         for page in self.pages:
             if page.orientation_change is True:
@@ -576,9 +716,7 @@ class PDFDocument(object):
 
     def _output_fonts(self):
         """ Called by the PDFLite object to prompt creating
-            the font objects.
-
-        """
+            the font objects."""
         self.session._save_object_number()
         self._output_encoding_diffs()
         self._output_font_files()
@@ -607,9 +745,7 @@ class PDFDocument(object):
 
     def _output_images(self):
         """ Creates reference images, that can be
-            drawn throughout the document.
-
-        """
+            drawn throughout the document."""
         for image in self.images:
             obj = self.session._add_object()
             image._set_number(obj.id)
