@@ -28,7 +28,6 @@ class PDFCursor(object):
         self.x = x
         self.y = y
 
-
     def __repr__(self):
         return "(%s, %s)" % (self.x, self.y)
 
@@ -62,7 +61,6 @@ class PDFCursor(object):
         else:
             self._x = value
 
-
     @property
     def y(self):
         return self._y
@@ -162,7 +160,7 @@ class PDFCursor(object):
     def copy(self):
         """ Create a copy, and return it."""
         new_cursor = self.__class__(self.x, self.y)
-        new_cursor.set_bounds(self.xmin, self.ymin, self.xmax, self.ymax)
+        new_cursor.set_bounds(self.xmin, self.ymin, self.xmax, self.ymax, self.ymaxmax)
         new_cursor.set_deltas(self.dx, self.dy)
         return new_cursor
 
